summaryrefslogtreecommitdiffstats
path: root/lib/overcloud-deploy-functions.sh
diff options
context:
space:
mode:
Diffstat (limited to 'lib/overcloud-deploy-functions.sh')
-rwxr-xr-xlib/overcloud-deploy-functions.sh7
1 files changed, 6 insertions, 1 deletions
diff --git a/lib/overcloud-deploy-functions.sh b/lib/overcloud-deploy-functions.sh
index d2ae027a..e8f19238 100755
--- a/lib/overcloud-deploy-functions.sh
+++ b/lib/overcloud-deploy-functions.sh
@@ -94,7 +94,12 @@ function overcloud_deploy {
DEPLOY_OPTIONS+=" -e /home/stack/enable_rt_kvm.yaml"
fi
- # Make sure the correct overcloud image is available
+ # Enable Barometer service
+ if [ "${deploy_options_array['barometer']}" == 'True' ]; then
+ DEPLOY_OPTIONS+=" -e /usr/share/openstack-tripleo-heat-templates/environments/enable_barometer.yaml"
+ fi
+
+# Make sure the correct overcloud image is available
if [ ! -f $IMAGES/overcloud-full-${SDN_IMAGE}.qcow2 ]; then
echo "${red} $IMAGES/overcloud-full-${SDN_IMAGE}.qcow2 is required to execute your deployment."
echo "Please install the opnfv-apex package to provide this overcloud image for deployment.${reset}"